from .src.admin_api import AdminAPI
from .src.query_api import QueryAPI
from .src.ingest_api import IngestAPI
import os

DEFAULT_BASE_URL = "https://api.formant.io/v1"


class Client:
    def __init__(
        self,
        email: str = None,
        password: str = None,
        base_url: str = DEFAULT_BASE_URL,
    ):
        self._email = os.getenv("FORMANT_EMAIL") if email is None else email
        self._password = os.getenv("FORMANT_PASSWORD") if password is None else password
        if self._email is None:
            raise ValueError(
                "email argument missing and FORMANT_EMAIL environment variable not set!"
            )
        if self._password is None:
            raise ValueError(
                "password argument missing and FORMANT_PASSWORD environment variable not set"
            )
        self.admin = AdminAPI(
            email=self._email, password=self._password, base_url=base_url
        )
        self.query = QueryAPI(
            email=self._email, password=self._password, base_url=base_url
        )
        self.ingest = IngestAPI(
            email=self._email, password=self._password, base_url=base_url
        )




from formant.sdk.cloud.v2.formant_admin_api_client.models import CommandDeliveryEventMetadata, DeviceOfflineEventType, CommentStreamType, InterventionRequestInterventionType, EventSeekQuerySeveritiesItem, DatapointEventMetadata, DatapointEventStreamType, CommandDeliveryEventType, DeviceOfflineEvent, EventSortColumn, EventTriggerCommand, FocusedDatapoint, TeleopSessionRecordTags, DatapointEventTags, TaskSummaryStreamType, TeleopSessionRecord, CommentMetadata, InterventionRequestTags, TaskSummaryReport, DatapointEventType, Label, TeleopRequestData, DeviceOfflineEventSeverity, CustomEvent, StatefulEventMetadata, CustomEventSeverity, EventQuery, SystemEvent, CommentTags, EventExportSheetResult, DatapointEvent, AnnotationMetadata, CommandDeliveryEvent, EventSeekQueryDirection, TaskSummary, StatefulEvent, EventHistogram, CommentType, InterventionRequestStreamType, PortForwardingSessionRecordStreamType, SystemEventTags, PortForwardingSessionRecord, DeviceOnlineEventMetadata, EventSeekQueryTypesItem, EventQuerySeveritiesItem, SystemEventMetadata, DeviceOnlineEvent, CustomEventStreamType, CustomEventMetadata, EventFilterSeveritiesItem, EventSortOrder, EventFilterTypesItem, TeleopSessionRecordType, EventFilter, EventQueryTypesItem, CustomEventType, SystemEventStreamType, StatefulEventStreamType, InterventionRequest, EventCounts, CustomEventTags, PhysicalRequestData, TaskSummaryTags, PortForwardingSessionRecordMetadata, TaskSummaryMetadata, SystemEventType, EventHistogramEntry, Annotation, Comment, EventListResponse, AnnotationTags, InterventionRequestType, TaskSummaryType, AnnotationStreamType, DeviceOnlineEventType, LabeledPolygon, PortForwardingSessionRecordTags, TeleopSessionRecordStreamType, LabelingRequestData, EventSeekQueryEventTypesItem, EventQueryEventTypesItem, EventSeekQuery, AnnotationType, DatapointEventSeverity, DeviceOnlineEventStreamType, DeviceOnlineEventSeverity, StatefulEventType, EventSort, DeviceOfflineEventMetadata, SelectionRequestData, PortForwardingSessionRecordType, TeleopSessionRecordMetadata, DeviceOfflineEventTags, EventExportSheetRequest, CommandDeliveryEventStreamType, DeviceOfflineEventStreamType, InterventionRequestMetadata, EventFilterEventTypesItem, CommandDeliveryEventTags, DeviceOnlineEventTags, InterventionRequestSeverity, StatefulEventTags, StatefulEventSeverity
from formant.sdk.cloud.v2.formant_admin_api_client.api.event import event_controller_query
from formant.sdk.cloud.v2.formant_admin_api_client.types import *




from formant.sdk.cloud.v2.formant_query_api_client.models import UuidListResponse, Metadata, StringListResponse, ScopeFilterTypesItem, MetadataListResponse, MetadataType, ScopeFilter, MetadataTags
from formant.sdk.cloud.v2.formant_query_api_client.api.metadata import metadata_controller_list_metadata, metadata_controller_list_stream_names, metadata_controller_list_device_ids
from formant.sdk.cloud.v2.formant_ingest_api_client.types import *



import datetime
from typing import Any, Dict, List, Type, TypeVar, Union

import attr
from dateutil.parser import isoparse

from ..models.usage_metrics_query_metric_type import UsageMetricsQueryMetricType
from ..types import UNSET, Unset

T = TypeVar("T", bound="UsageMetricsQuery")


@attr.s(auto_attribs=True)
class UsageMetricsQuery:
    """
    Attributes:
        start (datetime.datetime):
        end (datetime.datetime):
        metric_type (Union[Unset, UsageMetricsQueryMetricType]):
        detailed (Union[Unset, bool]):
    """

    start: datetime.datetime
    end: datetime.datetime
    metric_type: Union[Unset, UsageMetricsQueryMetricType] = UNSET
    detailed: Union[Unset, bool] = UNSET
    additional_properties: Dict[str, Any] = attr.ib(init=False, factory=dict)

    def to_dict(self) -> Dict[str, Any]:
        start = self.start.isoformat()

        end = self.end.isoformat()

        metric_type: Union[Unset, str] = UNSET
        if not isinstance(self.metric_type, Unset):
            metric_type = self.metric_type.value

        detailed = self.detailed

        field_dict: Dict[str, Any] = {}
        field_dict.update(self.additional_properties)
        field_dict.update(
            {
                "start": start,
                "end": end,
            }
        )
        if metric_type is not UNSET:
            field_dict["metricType"] = metric_type
        if detailed is not UNSET:
            field_dict["detailed"] = detailed

        return field_dict

    @classmethod
    def from_dict(cls: Type[T], src_dict: Dict[str, Any]) -> T:
        d = src_dict.copy()
        start = isoparse(d.pop("start"))

        end = isoparse(d.pop("end"))

        _metric_type = d.pop("metricType", UNSET)
        metric_type: Union[Unset, UsageMetricsQueryMetricType]
        if isinstance(_metric_type, Unset):
            metric_type = UNSET
        else:
            metric_type = UsageMetricsQueryMetricType(_metric_type)

        detailed = d.pop("detailed", UNSET)

        usage_metrics_query = cls(
            start=start,
            end=end,
            metric_type=metric_type,
            detailed=detailed,
        )

        usage_metrics_query.additional_properties = d
        return usage_metrics_query

    @property
    def additional_keys(self) -> List[str]:
        return list(self.additional_properties.keys())

    def __getitem__(self, key: str) -> Any:
        return self.additional_properties[key]

    def __setitem__(self, key: str, value: Any) -> None:
        self.additional_properties[key] = value

    def __delitem__(self, key: str) -> None:
        del self.additional_properties[key]

    def __contains__(self, key: str) -> bool:
        return key in self.additional_properties



from typing import Any, Dict, List, Type, TypeVar, Union, cast

import attr

from ..types import UNSET, Unset

T = TypeVar("T", bound="SchedulesQuery")


@attr.s(auto_attribs=True)
class SchedulesQuery:
    """
    Attributes:
        organization_id (Union[Unset, List[str]]):
        active (Union[Unset, bool]):
    """

    organization_id: Union[Unset, List[str]] = UNSET
    active: Union[Unset, bool] = UNSET
    additional_properties: Dict[str, Any] = attr.ib(init=False, factory=dict)

    def to_dict(self) -> Dict[str, Any]:
        organization_id: Union[Unset, List[str]] = UNSET
        if not isinstance(self.organization_id, Unset):
            organization_id = self.organization_id

        active = self.active

        field_dict: Dict[str, Any] = {}
        field_dict.update(self.additional_properties)
        field_dict.update({})
        if organization_id is not UNSET:
            field_dict["organizationId"] = organization_id
        if active is not UNSET:
            field_dict["active"] = active

        return field_dict

    @classmethod
    def from_dict(cls: Type[T], src_dict: Dict[str, Any]) -> T:
        d = src_dict.copy()
        organization_id = cast(List[str], d.pop("organizationId", UNSET))

        active = d.pop("active", UNSET)

        schedules_query = cls(
            organization_id=organization_id,
            active=active,
        )

        schedules_query.additional_properties = d
        return schedules_query

    @property
    def additional_keys(self) -> List[str]:
        return list(self.additional_properties.keys())

    def __getitem__(self, key: str) -> Any:
        return self.additional_properties[key]

    def __setitem__(self, key: str, value: Any) -> None:
        self.additional_properties[key] = value

    def __delitem__(self, key: str) -> None:
        del self.additional_properties[key]

    def __contains__(self, key: str) -> bool:
        return key in self.additional_properties




from . import Response, Command, CommandQuery, command_controller_post, command_controller_query
from formant.sdk.cloud.v2.src.resources.resources import Resources

class Commands(Resources):

    def create(self, command: Command):
        'Creates a command'
        client = self._get_client()
        response: Response[Command] = command_controller_post.sync_detailed(client=client, json_body=command)
        return response

    async def create_async(self, command: Command):
        'Creates a command'
        client = self._get_client()
        response: Response[Command] = (await command_controller_post.asyncio_detailed(client=client, json_body=command))
        return response

    def query(self, command_query: CommandQuery):
        'Query undelivered commands by device ID'
        client = self._get_client()
        response: Response[CommandQuery] = command_controller_query.sync_detailed(client=client, json_body=command_query)
        return response

    async def query_async(self, command_query: CommandQuery):
        'Query undelivered commands by device ID'
        client = self._get_client()
        response: Response[CommandQuery] = (await command_controller_query.asyncio_detailed(client=client, json_body=command_query))
        return response



from typing import Any, Dict, List, Type, TypeVar

import attr

T = TypeVar("T", bound="PagerdutyInfo")


@attr.s(auto_attribs=True)
class PagerdutyInfo:
    """
    Attributes:
        account (str):
        service_name (str):
        service_key (str):
    """

    account: str
    service_name: str
    service_key: str
    additional_properties: Dict[str, Any] = attr.ib(init=False, factory=dict)

    def to_dict(self) -> Dict[str, Any]:
        account = self.account
        service_name = self.service_name
        service_key = self.service_key

        field_dict: Dict[str, Any] = {}
        field_dict.update(self.additional_properties)
        field_dict.update(
            {
                "account": account,
                "serviceName": service_name,
                "serviceKey": service_key,
            }
        )

        return field_dict

    @classmethod
    def from_dict(cls: Type[T], src_dict: Dict[str, Any]) -> T:
        d = src_dict.copy()
        account = d.pop("account")

        service_name = d.pop("serviceName")

        service_key = d.pop("serviceKey")

        pagerduty_info = cls(
            account=account,
            service_name=service_name,
            service_key=service_key,
        )

        pagerduty_info.additional_properties = d
        return pagerduty_info

    @property
    def additional_keys(self) -> List[str]:
        return list(self.additional_properties.keys())

    def __getitem__(self, key: str) -> Any:
        return self.additional_properties[key]

    def __setitem__(self, key: str, value: Any) -> None:
        self.additional_properties[key] = value

    def __delitem__(self, key: str) -> None:
        del self.additional_properties[key]

    def __contains__(self, key: str) -> bool:
        return key in self.additional_properties



from typing import Callable, Dict, Optional, Type
import json
import jsonschema
import logging
from threading import Lock
from functools import reduce
import re

from formant.sdk.agent.v1.client import Client as AgentClient

logging.basicConfig()

JSONDecodeError = Exception  # type: Type[Exception]
try:
    JSONDecodeError = json.decoder.JSONDecodeError
except AttributeError:
    # python2 doesn't have JSON Decode Error
    pass


class JsonSchemaValidator:
    def __init__(
        self,
        client,  # type: AgentClient
        adapter_name,  # type: str
        update_adapter_config_callback,  # type: Callable[[Dict], None]
        validate=True,  # type: bool
        use_app_config=True,  # type: bool
        logger=None,  # type: Optional[logging.Logger]
        logger_level=logging.INFO,  # type: int
    ):
        self._lock = Lock()
        self._client = client
        self._adapter_name = adapter_name
        self._update_adapter_config_callback = update_adapter_config_callback
        self._use_app_config = use_app_config
        self._validate = validate
        if logger is None:
            logger = logging.getLogger(adapter_name)
            logger.setLevel(logger_level)
        self.logger = logger
        self._client.register_config_update_callback(self._update_adapter_config)
        if self._client.ignore_unavailable:
            self._update_adapter_config()

    def _update_adapter_config(self):
        # Consumer might not be threadsafe
        with self._lock:
            try:
                configs = [
                    self._get_config_from_adapter_configuration(),
                    self._get_config_from_blob_data(),
                    self._get_config_from_json(),
                ]
                config = reduce(lambda s1, s2: s1 or s2, configs)
                if config is None:
                    raise Exception(
                        "Could not get configuration for '%s'" % self._adapter_name
                    )
                if self._use_app_config:
                    config = self._inject_app_config(config)
                if self._validate:
                    self._validate_schema(config)
                try:
                    self._update_adapter_config_callback(config)
                except Exception as e:
                    self.logger.error(
                        "Error calling update config callback %s" % str(e)
                    )
            except Exception as e:
                self.logger.warn("Failed to load config: %s" % str(e))
                self._client.create_event(
                    "%s configuration loading failed: %s."
                    % (self._adapter_name, str(e)),
                    notify=False,
                    severity="warning",
                )

    def _get_config_from_adapter_configuration(self):
        self.logger.info("Trying to get config from adapter config")
        try:
            adapters = self._client.get_agent_configuration().document.adapters
            for adapter in adapters:
                config = json.loads(adapter.configuration)
                if self._adapter_name in config:
                    self.logger.info("Got config from adapter config")
                    return config
        except Exception as e:
            self.logger.warn("Error getting config from adapter config: %s" % str(e))
        return None

    def _get_config_from_blob_data(self):
        self.logger.info("Trying to get config from blob data")
        try:
            config = json.loads(self._client.get_config_blob_data())
            if self._adapter_name in config:
                self.logger.info("Got config from blob data")
                return config
        except Exception as e:
            self.logger.info("Error getting config from blob data: %s" % str(e))
        return None

    def _inject_app_config(self, config: Dict):
        """
        This function replaces all instances of
        {{key}} with `key` from app_config
        """
        config_string = json.dumps(config)
        pattern = r"\{\{(.+?)\}\}"
        matches = re.findall(pattern, config_string)
        for match in matches:
            val = self._client.get_app_config(match)
            config_string = config_string.replace("{{%s}}" % match, val)
        return json.loads(config_string)

    def _get_config_from_json(self):
        # Try to get config from config.json
        self.logger.info("Trying to get config from config.json file")
        try:
            with open("config.json") as f:
                config = json.loads(f.read())
                if self._adapter_name in config:
                    self.logger.info("Got config from config.json file")
                    return config
        except Exception as e:
            self.logger.info("Error getting config from config.json: %s" % str(e))
        return None

    def _validate_schema(self, config_blob):
        # Validate configuration based on schema
        with open("config_schema.json") as f:
            try:
                self.config_schema = json.load(f)
                self.logger.info("Loaded config schema from config_schema.json file")
            except JSONDecodeError as e:
                self.logger.warn(
                    "Could not load config schema. Is the file valid json?"
                )
                raise Exception("config schema error: %s" % str(e))
        self.logger.info("Validating config...")
        try:
            jsonschema.validate(config_blob, self.config_schema)
            self.logger.info("Validation succeeded")
        except (
            jsonschema.ValidationError,
            jsonschema.SchemaError,
            jsonschema.RefResolutionError,
        ) as e:
            self.logger.warn("Validation failed %s: %s", type(e).__name__, str(e))
        except Exception as e:
            self.logger.warn(
                "Validation failed with unkown error %s: %s", type(e).__name__, str(e)
            )




from formant.sdk.cloud.v2.formant_query_api_client.models import UuidListResponse, ActiveDevicesQueryType, ActiveDevicesQuery
from formant.sdk.cloud.v2.formant_query_api_client.api.count import count_controller_active_devices
from formant.sdk.cloud.v2.formant_query_api_client.types import *



from typing import TYPE_CHECKING, Any, Dict, List, Type, TypeVar

import attr

if TYPE_CHECKING:
    from ..models.location import Location


T = TypeVar("T", bound="LocationViewport")


@attr.s(auto_attribs=True)
class LocationViewport:
    """
    Attributes:
        center (Location):
        zoom (float):
    """

    center: "Location"
    zoom: float
    additional_properties: Dict[str, Any] = attr.ib(init=False, factory=dict)

    def to_dict(self) -> Dict[str, Any]:
        center = self.center.to_dict()

        zoom = self.zoom

        field_dict: Dict[str, Any] = {}
        field_dict.update(self.additional_properties)
        field_dict.update(
            {
                "center": center,
                "zoom": zoom,
            }
        )

        return field_dict

    @classmethod
    def from_dict(cls: Type[T], src_dict: Dict[str, Any]) -> T:
        from ..models.location import Location

        d = src_dict.copy()
        center = Location.from_dict(d.pop("center"))

        zoom = d.pop("zoom")

        location_viewport = cls(
            center=center,
            zoom=zoom,
        )

        location_viewport.additional_properties = d
        return location_viewport

    @property
    def additional_keys(self) -> List[str]:
        return list(self.additional_properties.keys())

    def __getitem__(self, key: str) -> Any:
        return self.additional_properties[key]

    def __setitem__(self, key: str, value: Any) -> None:
        self.additional_properties[key] = value

    def __delitem__(self, key: str) -> None:
        del self.additional_properties[key]

    def __contains__(self, key: str) -> bool:
        return key in self.additional_properties




from formant.sdk.cloud.v2.formant_admin_api_client.models import AnnotationFieldValue, AnnotationTemplateListResponse, AnnotationFieldValueTags, AnnotationType, ScopeFilterTypesItem, SheetParameters, AnnotationMetadata, AnnotationTemplate, AnnotationFieldValuesRequestTags, AnnotationTemplateTags, AnnotationFieldValuesRequest, ScopeFilter, AnnotationFieldType, UserParametersRolesItem, FocusedDatapoint, UserParameters, AnnotationField, Annotation, TagParameters, AnnotationTags, AnnotationFieldValuesResponse, AnnotationStreamType
from formant.sdk.cloud.v2.formant_admin_api_client.api.annotation import annotation_controller_post
from formant.sdk.cloud.v2.formant_admin_api_client.api.annotation_template import annotation_template_controller_list, annotation_template_controller_get_one
from formant.sdk.cloud.v2.formant_admin_api_client.types import *



from typing import TYPE_CHECKING, Any, Dict, List, Type, TypeVar

import attr

if TYPE_CHECKING:
    from ..models.stream import Stream


T = TypeVar("T", bound="StreamListResponse")


@attr.s(auto_attribs=True)
class StreamListResponse:
    """
    Attributes:
        items (List['Stream']):
    """

    items: List["Stream"]
    additional_properties: Dict[str, Any] = attr.ib(init=False, factory=dict)

    def to_dict(self) -> Dict[str, Any]:
        items = []
        for items_item_data in self.items:
            items_item = items_item_data.to_dict()

            items.append(items_item)

        field_dict: Dict[str, Any] = {}
        field_dict.update(self.additional_properties)
        field_dict.update(
            {
                "items": items,
            }
        )

        return field_dict

    @classmethod
    def from_dict(cls: Type[T], src_dict: Dict[str, Any]) -> T:
        from ..models.stream import Stream

        d = src_dict.copy()
        items = []
        _items = d.pop("items")
        for items_item_data in _items:
            items_item = Stream.from_dict(items_item_data)

            items.append(items_item)

        stream_list_response = cls(
            items=items,
        )

        stream_list_response.additional_properties = d
        return stream_list_response

    @property
    def additional_keys(self) -> List[str]:
        return list(self.additional_properties.keys())

    def __getitem__(self, key: str) -> Any:
        return self.additional_properties[key]

    def __setitem__(self, key: str, value: Any) -> None:
        self.additional_properties[key] = value

    def __delitem__(self, key: str) -> None:
        del self.additional_properties[key]

    def __contains__(self, key: str) -> bool:
        return key in self.additional_properties



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: protos/model/v1/datapoint.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from formant.protos.model.v1 import file_pb2 as protos_dot_model_dot_v1_dot_file__pb2
from formant.protos.model.v1 import health_pb2 as protos_dot_model_dot_v1_dot_health__pb2
from formant.protos.model.v1 import math_pb2 as protos_dot_model_dot_v1_dot_math__pb2
from formant.protos.model.v1 import navigation_pb2 as protos_dot_model_dot_v1_dot_navigation__pb2
from formant.protos.model.v1 import text_pb2 as protos_dot_model_dot_v1_dot_text__pb2
from formant.protos.model.v1 import media_pb2 as protos_dot_model_dot_v1_dot_media__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='protos/model/v1/datapoint.proto',
  package='v1.model',
  syntax='proto3',
  serialized_options=b'Z)github.com/FormantIO/genproto/go/v1/model',
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n\x1fprotos/model/v1/datapoint.proto\x12\x08v1.model\x1a\x1aprotos/model/v1/file.proto\x1a\x1cprotos/model/v1/health.proto\x1a\x1aprotos/model/v1/math.proto\x1a protos/model/v1/navigation.proto\x1a\x1aprotos/model/v1/text.proto\x1a\x1bprotos/model/v1/media.proto\"\xdb\x05\n\tDatapoint\x12\x0e\n\x06stream\x18\x01 \x01(\t\x12\x11\n\ttimestamp\x18\x02 \x01(\x03\x12+\n\x04tags\x18\x03 \x03(\x0b\x32\x1d.v1.model.Datapoint.TagsEntry\x12\x1e\n\x04text\x18\x04 \x01(\x0b\x32\x0e.v1.model.TextH\x00\x12$\n\x07numeric\x18\x05 \x01(\x0b\x32\x11.v1.model.NumericH\x00\x12+\n\x0bnumeric_set\x18\x11 \x01(\x0b\x32\x14.v1.model.NumericSetH\x00\x12\"\n\x06\x62itset\x18\x07 \x01(\x0b\x32\x10.v1.model.BitsetH\x00\x12\x1e\n\x04\x66ile\x18\x08 \x01(\x0b\x32\x0e.v1.model.FileH\x00\x12 \n\x05image\x18\t \x01(\x0b\x32\x0f.v1.model.ImageH\x00\x12+\n\x0bpoint_cloud\x18\n \x01(\x0b\x32\x14.v1.model.PointCloudH\x00\x12&\n\x08location\x18\x0b \x01(\x0b\x32\x12.v1.model.LocationH\x00\x12.\n\x0clocalization\x18\x0c \x01(\x0b\x32\x16.v1.model.LocalizationH\x00\x12\"\n\x06health\x18\r \x01(\x0b\x32\x10.v1.model.HealthH\x00\x12\x1e\n\x04json\x18\x0e \x01(\x0b\x32\x0e.v1.model.JsonH\x00\x12$\n\x07\x62\x61ttery\x18\x0f \x01(\x0b\x32\x11.v1.model.BatteryH\x00\x12 \n\x05video\x18\x10 \x01(\x0b\x32\x0f.v1.model.VideoH\x00\x12\x31\n\x0etransform_tree\x18\x12 \x01(\x0b\x32\x17.v1.model.TransformTreeH\x00\x12&\n\x08odometry\x18\x13 \x01(\x0b\x32\x12.v1.model.OdometryH\x00\x1a+\n\tTagsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\x42\x06\n\x04\x64\x61taJ\x04\x08\x06\x10\x07\"\xcc\x02\n\x10\x43ontrolDatapoint\x12\x0e\n\x06stream\x18\x01 \x01(\t\x12\x11\n\ttimestamp\x18\x02 \x01(\x03\x12\"\n\x06\x62itset\x18\x03 \x01(\x0b\x32\x10.v1.model.BitsetH\x00\x12 \n\x05twist\x18\x04 \x01(\x0b\x32\x0f.v1.model.TwistH\x00\x12#\n\x04pose\x18\x05 \x01(\x0b\x32\x13.v1.model.TransformH\x00\x12$\n\x07numeric\x18\x06 \x01(\x0b\x32\x11.v1.model.NumericH\x00\x12<\n\x14pose_with_covariance\x18\x07 \x01(\x0b\x32\x1c.v1.model.PoseWithCovarianceH\x00\x12 \n\x05point\x18\x08 \x01(\x0b\x32\x0f.v1.model.PointH\x00\x12\x1c\n\x03joy\x18\t \x01(\x0b\x32\r.v1.model.JoyH\x00\x42\x06\n\x04\x64\x61ta\"\x81\x02\n\x13GenericAPIDatapoint\x12\x0e\n\x06Method\x18\x01 \x01(\t\x12\x10\n\x08\x45ndpoint\x18\x02 \x01(\t\x12;\n\x07Headers\x18\x03 \x03(\x0b\x32*.v1.model.GenericAPIDatapoint.HeadersEntry\x12\x0c\n\x04\x42ody\x18\x04 \x01(\t\x12\x13\n\x0bIsRetryable\x18\x05 \x01(\x08\x12\x1a\n\x12RequireFormantAuth\x18\x06 \x01(\x08\x12\x1c\n\x14RetryableStatusCodes\x18\x07 \x03(\x03\x1a.\n\x0cHeadersEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\x42+Z)github.com/FormantIO/genproto/go/v1/modelb\x06proto3'
  ,
  dependencies=[protos_dot_model_dot_v1_dot_file__pb2.DESCRIPTOR,protos_dot_model_dot_v1_dot_health__pb2.DESCRIPTOR,protos_dot_model_dot_v1_dot_math__pb2.DESCRIPTOR,protos_dot_model_dot_v1_dot_navigation__pb2.DESCRIPTOR,protos_dot_model_dot_v1_dot_text__pb2.DESCRIPTOR,protos_dot_model_dot_v1_dot_media__pb2.DESCRIPTOR,])




_DATAPOINT_TAGSENTRY = _descriptor.Descriptor(
  name='TagsEntry',
  full_name='v1.model.Datapoint.TagsEntry',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='key', full_name='v1.model.Datapoint.TagsEntry.key', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='value', full_name='v1.model.Datapoint.TagsEntry.value', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'8\001',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=897,
  serialized_end=940,
)

_DATAPOINT = _descriptor.Descriptor(
  name='Datapoint',
  full_name='v1.model.Datapoint',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='stream', full_name='v1.model.Datapoint.stream', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='timestamp', full_name='v1.model.Datapoint.timestamp', index=1,
      number=2, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='tags', full_name='v1.model.Datapoint.tags', index=2,
      number=3, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='text', full_name='v1.model.Datapoint.text', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='numeric', full_name='v1.model.Datapoint.numeric', index=4,
      number=5, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='numeric_set', full_name='v1.model.Datapoint.numeric_set', index=5,
      number=17, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='bitset', full_name='v1.model.Datapoint.bitset', index=6,
      number=7, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='file', full_name='v1.model.Datapoint.file', index=7,
      number=8, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='image', full_name='v1.model.Datapoint.image', index=8,
      number=9, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='point_cloud', full_name='v1.model.Datapoint.point_cloud', index=9,
      number=10, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='location', full_name='v1.model.Datapoint.location', index=10,
      number=11, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='localization', full_name='v1.model.Datapoint.localization', index=11,
      number=12, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='health', full_name='v1.model.Datapoint.health', index=12,
      number=13, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='json', full_name='v1.model.Datapoint.json', index=13,
      number=14, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='battery', full_name='v1.model.Datapoint.battery', index=14,
      number=15, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='video', full_name='v1.model.Datapoint.video', index=15,
      number=16, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='transform_tree', full_name='v1.model.Datapoint.transform_tree', index=16,
      number=18, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='odometry', full_name='v1.model.Datapoint.odometry', index=17,
      number=19, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[_DATAPOINT_TAGSENTRY, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='data', full_name='v1.model.Datapoint.data',
      index=0, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
  ],
  serialized_start=223,
  serialized_end=954,
)


_CONTROLDATAPOINT = _descriptor.Descriptor(
  name='ControlDatapoint',
  full_name='v1.model.ControlDatapoint',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='stream', full_name='v1.model.ControlDatapoint.stream', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='timestamp', full_name='v1.model.ControlDatapoint.timestamp', index=1,
      number=2, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='bitset', full_name='v1.model.ControlDatapoint.bitset', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='twist', full_name='v1.model.ControlDatapoint.twist', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='pose', full_name='v1.model.ControlDatapoint.pose', index=4,
      number=5, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='numeric', full_name='v1.model.ControlDatapoint.numeric', index=5,
      number=6, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='pose_with_covariance', full_name='v1.model.ControlDatapoint.pose_with_covariance', index=6,
      number=7, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='point', full_name='v1.model.ControlDatapoint.point', index=7,
      number=8, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='joy', full_name='v1.model.ControlDatapoint.joy', index=8,
      number=9, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='data', full_name='v1.model.ControlDatapoint.data',
      index=0, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
  ],
  serialized_start=957,
  serialized_end=1289,
)


_GENERICAPIDATAPOINT_HEADERSENTRY = _descriptor.Descriptor(
  name='HeadersEntry',
  full_name='v1.model.GenericAPIDatapoint.HeadersEntry',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='key', full_name='v1.model.GenericAPIDatapoint.HeadersEntry.key', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='value', full_name='v1.model.GenericAPIDatapoint.HeadersEntry.value', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'8\001',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1503,
  serialized_end=1549,
)

_GENERICAPIDATAPOINT = _descriptor.Descriptor(
  name='GenericAPIDatapoint',
  full_name='v1.model.GenericAPIDatapoint',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='Method', full_name='v1.model.GenericAPIDatapoint.Method', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='Endpoint', full_name='v1.model.GenericAPIDatapoint.Endpoint', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='Headers', full_name='v1.model.GenericAPIDatapoint.Headers', index=2,
      number=3, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='Body', full_name='v1.model.GenericAPIDatapoint.Body', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='IsRetryable', full_name='v1.model.GenericAPIDatapoint.IsRetryable', index=4,
      number=5, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='RequireFormantAuth', full_name='v1.model.GenericAPIDatapoint.RequireFormantAuth', index=5,
      number=6, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='RetryableStatusCodes', full_name='v1.model.GenericAPIDatapoint.RetryableStatusCodes', index=6,
      number=7, type=3, cpp_type=2, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[_GENERICAPIDATAPOINT_HEADERSENTRY, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1292,
  serialized_end=1549,
)

_DATAPOINT_TAGSENTRY.containing_type = _DATAPOINT
_DATAPOINT.fields_by_name['tags'].message_type = _DATAPOINT_TAGSENTRY
_DATAPOINT.fields_by_name['text'].message_type = protos_dot_model_dot_v1_dot_text__pb2._TEXT
_DATAPOINT.fields_by_name['numeric'].message_type = protos_dot_model_dot_v1_dot_math__pb2._NUMERIC
_DATAPOINT.fields_by_name['numeric_set'].message_type = protos_dot_model_dot_v1_dot_math__pb2._NUMERICSET
_DATAPOINT.fields_by_name['bitset'].message_type = protos_dot_model_dot_v1_dot_math__pb2._BITSET
_DATAPOINT.fields_by_name['file'].message_type = protos_dot_model_dot_v1_dot_file__pb2._FILE
_DATAPOINT.fields_by_name['image'].message_type = protos_dot_model_dot_v1_dot_media__pb2._IMAGE
_DATAPOINT.fields_by_name['point_cloud'].message_type = protos_dot_model_dot_v1_dot_media__pb2._POINTCLOUD
_DATAPOINT.fields_by_name['location'].message_type = protos_dot_model_dot_v1_dot_navigation__pb2._LOCATION
_DATAPOINT.fields_by_name['localization'].message_type = protos_dot_model_dot_v1_dot_navigation__pb2._LOCALIZATION
_DATAPOINT.fields_by_name['health'].message_type = protos_dot_model_dot_v1_dot_health__pb2._HEALTH
_DATAPOINT.fields_by_name['json'].message_type = protos_dot_model_dot_v1_dot_text__pb2._JSON
_DATAPOINT.fields_by_name['battery'].message_type = protos_dot_model_dot_v1_dot_health__pb2._BATTERY
_DATAPOINT.fields_by_name['video'].message_type = protos_dot_model_dot_v1_dot_media__pb2._VIDEO
_DATAPOINT.fields_by_name['transform_tree'].message_type = protos_dot_model_dot_v1_dot_media__pb2._TRANSFORMTREE
_DATAPOINT.fields_by_name['odometry'].message_type = protos_dot_model_dot_v1_dot_navigation__pb2._ODOMETRY
_DATAPOINT.oneofs_by_name['data'].fields.append(
  _DATAPOINT.fields_by_name['text'])
_DATAPOINT.fields_by_name['text'].containing_oneof = _DATAPOINT.oneofs_by_name['data']
_DATAPOINT.oneofs_by_name['data'].fields.append(
  _DATAPOINT.fields_by_name['numeric'])
_DATAPOINT.fields_by_name['numeric'].containing_oneof = _DATAPOINT.oneofs_by_name['data']
_DATAPOINT.oneofs_by_name['data'].fields.append(
  _DATAPOINT.fields_by_name['numeric_set'])
_DATAPOINT.fields_by_name['numeric_set'].containing_oneof = _DATAPOINT.oneofs_by_name['data']
_DATAPOINT.oneofs_by_name['data'].fields.append(
  _DATAPOINT.fields_by_name['bitset'])
_DATAPOINT.fields_by_name['bitset'].containing_oneof = _DATAPOINT.oneofs_by_name['data']
_DATAPOINT.oneofs_by_name['data'].fields.append(
  _DATAPOINT.fields_by_name['file'])
_DATAPOINT.fields_by_name['file'].containing_oneof = _DATAPOINT.oneofs_by_name['data']
_DATAPOINT.oneofs_by_name['data'].fields.append(
  _DATAPOINT.fields_by_name['image'])
_DATAPOINT.fields_by_name['image'].containing_oneof = _DATAPOINT.oneofs_by_name['data']
_DATAPOINT.oneofs_by_name['data'].fields.append(
  _DATAPOINT.fields_by_name['point_cloud'])
_DATAPOINT.fields_by_name['point_cloud'].containing_oneof = _DATAPOINT.oneofs_by_name['data']
_DATAPOINT.oneofs_by_name['data'].fields.append(
  _DATAPOINT.fields_by_name['location'])
_DATAPOINT.fields_by_name['location'].containing_oneof = _DATAPOINT.oneofs_by_name['data']
_DATAPOINT.oneofs_by_name['data'].fields.append(
  _DATAPOINT.fields_by_name['localization'])
_DATAPOINT.fields_by_name['localization'].containing_oneof = _DATAPOINT.oneofs_by_name['data']
_DATAPOINT.oneofs_by_name['data'].fields.append(
  _DATAPOINT.fields_by_name['health'])
_DATAPOINT.fields_by_name['health'].containing_oneof = _DATAPOINT.oneofs_by_name['data']
_DATAPOINT.oneofs_by_name['data'].fields.append(
  _DATAPOINT.fields_by_name['json'])
_DATAPOINT.fields_by_name['json'].containing_oneof = _DATAPOINT.oneofs_by_name['data']
_DATAPOINT.oneofs_by_name['data'].fields.append(
  _DATAPOINT.fields_by_name['battery'])
_DATAPOINT.fields_by_name['battery'].containing_oneof = _DATAPOINT.oneofs_by_name['data']
_DATAPOINT.oneofs_by_name['data'].fields.append(
  _DATAPOINT.fields_by_name['video'])
_DATAPOINT.fields_by_name['video'].containing_oneof = _DATAPOINT.oneofs_by_name['data']
_DATAPOINT.oneofs_by_name['data'].fields.append(
  _DATAPOINT.fields_by_name['transform_tree'])
_DATAPOINT.fields_by_name['transform_tree'].containing_oneof = _DATAPOINT.oneofs_by_name['data']
_DATAPOINT.oneofs_by_name['data'].fields.append(
  _DATAPOINT.fields_by_name['odometry'])
_DATAPOINT.fields_by_name['odometry'].containing_oneof = _DATAPOINT.oneofs_by_name['data']
_CONTROLDATAPOINT.fields_by_name['bitset'].message_type = protos_dot_model_dot_v1_dot_math__pb2._BITSET
_CONTROLDATAPOINT.fields_by_name['twist'].message_type = protos_dot_model_dot_v1_dot_math__pb2._TWIST
_CONTROLDATAPOINT.fields_by_name['pose'].message_type = protos_dot_model_dot_v1_dot_math__pb2._TRANSFORM
_CONTROLDATAPOINT.fields_by_name['numeric'].message_type = protos_dot_model_dot_v1_dot_math__pb2._NUMERIC
_CONTROLDATAPOINT.fields_by_name['pose_with_covariance'].message_type = protos_dot_model_dot_v1_dot_navigation__pb2._POSEWITHCOVARIANCE
_CONTROLDATAPOINT.fields_by_name['point'].message_type = protos_dot_model_dot_v1_dot_math__pb2._POINT
_CONTROLDATAPOINT.fields_by_name['joy'].message_type = protos_dot_model_dot_v1_dot_navigation__pb2._JOY
_CONTROLDATAPOINT.oneofs_by_name['data'].fields.append(
  _CONTROLDATAPOINT.fields_by_name['bitset'])
_CONTROLDATAPOINT.fields_by_name['bitset'].containing_oneof = _CONTROLDATAPOINT.oneofs_by_name['data']
_CONTROLDATAPOINT.oneofs_by_name['data'].fields.append(
  _CONTROLDATAPOINT.fields_by_name['twist'])
_CONTROLDATAPOINT.fields_by_name['twist'].containing_oneof = _CONTROLDATAPOINT.oneofs_by_name['data']
_CONTROLDATAPOINT.oneofs_by_name['data'].fields.append(
  _CONTROLDATAPOINT.fields_by_name['pose'])
_CONTROLDATAPOINT.fields_by_name['pose'].containing_oneof = _CONTROLDATAPOINT.oneofs_by_name['data']
_CONTROLDATAPOINT.oneofs_by_name['data'].fields.append(
  _CONTROLDATAPOINT.fields_by_name['numeric'])
_CONTROLDATAPOINT.fields_by_name['numeric'].containing_oneof = _CONTROLDATAPOINT.oneofs_by_name['data']
_CONTROLDATAPOINT.oneofs_by_name['data'].fields.append(
  _CONTROLDATAPOINT.fields_by_name['pose_with_covariance'])
_CONTROLDATAPOINT.fields_by_name['pose_with_covariance'].containing_oneof = _CONTROLDATAPOINT.oneofs_by_name['data']
_CONTROLDATAPOINT.oneofs_by_name['data'].fields.append(
  _CONTROLDATAPOINT.fields_by_name['point'])
_CONTROLDATAPOINT.fields_by_name['point'].containing_oneof = _CONTROLDATAPOINT.oneofs_by_name['data']
_CONTROLDATAPOINT.oneofs_by_name['data'].fields.append(
  _CONTROLDATAPOINT.fields_by_name['joy'])
_CONTROLDATAPOINT.fields_by_name['joy'].containing_oneof = _CONTROLDATAPOINT.oneofs_by_name['data']
_GENERICAPIDATAPOINT_HEADERSENTRY.containing_type = _GENERICAPIDATAPOINT
_GENERICAPIDATAPOINT.fields_by_name['Headers'].message_type = _GENERICAPIDATAPOINT_HEADERSENTRY
DESCRIPTOR.message_types_by_name['Datapoint'] = _DATAPOINT
DESCRIPTOR.message_types_by_name['ControlDatapoint'] = _CONTROLDATAPOINT
DESCRIPTOR.message_types_by_name['GenericAPIDatapoint'] = _GENERICAPIDATAPOINT
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

Datapoint = _reflection.GeneratedProtocolMessageType('Datapoint', (_message.Message,), {

  'TagsEntry' : _reflection.GeneratedProtocolMessageType('TagsEntry', (_message.Message,), {
    'DESCRIPTOR' : _DATAPOINT_TAGSENTRY,
    '__module__' : 'protos.model.v1.datapoint_pb2'
    # @@protoc_insertion_point(class_scope:v1.model.Datapoint.TagsEntry)
    })
  ,
  'DESCRIPTOR' : _DATAPOINT,
  '__module__' : 'protos.model.v1.datapoint_pb2'
  # @@protoc_insertion_point(class_scope:v1.model.Datapoint)
  })
_sym_db.RegisterMessage(Datapoint)
_sym_db.RegisterMessage(Datapoint.TagsEntry)

ControlDatapoint = _reflection.GeneratedProtocolMessageType('ControlDatapoint', (_message.Message,), {
  'DESCRIPTOR' : _CONTROLDATAPOINT,
  '__module__' : 'protos.model.v1.datapoint_pb2'
  # @@protoc_insertion_point(class_scope:v1.model.ControlDatapoint)
  })
_sym_db.RegisterMessage(ControlDatapoint)

GenericAPIDatapoint = _reflection.GeneratedProtocolMessageType('GenericAPIDatapoint', (_message.Message,), {

  'HeadersEntry' : _reflection.GeneratedProtocolMessageType('HeadersEntry', (_message.Message,), {
    'DESCRIPTOR' : _GENERICAPIDATAPOINT_HEADERSENTRY,
    '__module__' : 'protos.model.v1.datapoint_pb2'
    # @@protoc_insertion_point(class_scope:v1.model.GenericAPIDatapoint.HeadersEntry)
    })
  ,
  'DESCRIPTOR' : _GENERICAPIDATAPOINT,
  '__module__' : 'protos.model.v1.datapoint_pb2'
  # @@protoc_insertion_point(class_scope:v1.model.GenericAPIDatapoint)
  })
_sym_db.RegisterMessage(GenericAPIDatapoint)
_sym_db.RegisterMessage(GenericAPIDatapoint.HeadersEntry)


DESCRIPTOR._options = None
_DATAPOINT_TAGSENTRY._options = None
_GENERICAPIDATAPOINT_HEADERSENTRY._options = None
# @@protoc_insertion_point(module_scope)




from . import Response, AnnotationTemplateListResponse, AnnotationTemplate, Annotation, annotation_template_controller_list, annotation_template_controller_get_one, annotation_controller_post
from formant.sdk.cloud.v2.src.resources.resources import Resources

class Annotations(Resources):

    def list_templates(self):
        'List all annotations'
        client = self._get_client()
        response: Response[AnnotationTemplateListResponse] = annotation_template_controller_list.sync_detailed(client=client)
        return response

    async def list_templates_async(self):
        'List all annotations'
        client = self._get_client()
        response: Response[AnnotationTemplateListResponse] = (await annotation_template_controller_list.asyncio_detailed(client=client))
        return response

    def get_template(self, id: str):
        'Get an annotation'
        client = self._get_client()
        response: Response[AnnotationTemplate] = annotation_template_controller_get_one.sync_detailed(client=client, id=id)
        return response

    async def get_template_async(self, id: str):
        'Get an annotation'
        client = self._get_client()
        response: Response[AnnotationTemplate] = (await annotation_template_controller_get_one.asyncio_detailed(client=client, id=id))
        return response

    def post(self, annotation: Annotation):
        'Creates an annotation'
        client = self._get_client()
        response: Response[Annotation] = annotation_controller_post.sync_detailed(client=client, json_body=annotation)
        return response

    async def post_async(self, annotation: Annotation):
        'Creates an annotation'
        client = self._get_client()
        response: Response[Annotation] = (await annotation_controller_post.asyncio_detailed(client=client, json_body=annotation))
        return response



from typing import Dict, List
from .annotation_field import AnnotationField


class AnnotationTemplate:
    def __init__(
        self, annotation_template_response  # type: Dict
    ):
        self.id = annotation_template_response["id"]  # type: str
        self.name = annotation_template_response["name"]  # type: str
        self.description = annotation_template_response["description"]  # type: str
        self.enabled = annotation_template_response["enabled"]  # type: str
        self.fields = list(
            map(
                lambda field: AnnotationField(field),
                annotation_template_response["fields"],
            )
        )  # type: List[AnnotationField]

    def get_required_tag_fields(self):
        return list(
            filter(lambda field: field.required and field.type == "tag", self.fields)
        )



from typing import Any, Dict, List, Type, TypeVar, Union

import attr

from ..types import UNSET, Unset

T = TypeVar("T", bound="DeviceDiagnosticsConfiguration")


@attr.s(auto_attribs=True)
class DeviceDiagnosticsConfiguration:
    """
    Attributes:
        report_logs (Union[Unset, None, bool]):
        ingest_logs (Union[Unset, None, bool]):
        report_metrics (Union[Unset, None, bool]):
    """

    report_logs: Union[Unset, None, bool] = UNSET
    ingest_logs: Union[Unset, None, bool] = UNSET
    report_metrics: Union[Unset, None, bool] = UNSET
    additional_properties: Dict[str, Any] = attr.ib(init=False, factory=dict)

    def to_dict(self) -> Dict[str, Any]:
        report_logs = self.report_logs
        ingest_logs = self.ingest_logs
        report_metrics = self.report_metrics

        field_dict: Dict[str, Any] = {}
        field_dict.update(self.additional_properties)
        field_dict.update({})
        if report_logs is not UNSET:
            field_dict["reportLogs"] = report_logs
        if ingest_logs is not UNSET:
            field_dict["ingestLogs"] = ingest_logs
        if report_metrics is not UNSET:
            field_dict["reportMetrics"] = report_metrics

        return field_dict

    @classmethod
    def from_dict(cls: Type[T], src_dict: Dict[str, Any]) -> T:
        d = src_dict.copy()
        report_logs = d.pop("reportLogs", UNSET)

        ingest_logs = d.pop("ingestLogs", UNSET)

        report_metrics = d.pop("reportMetrics", UNSET)

        device_diagnostics_configuration = cls(
            report_logs=report_logs,
            ingest_logs=ingest_logs,
            report_metrics=report_metrics,
        )

        device_diagnostics_configuration.additional_properties = d
        return device_diagnostics_configuration

    @property
    def additional_keys(self) -> List[str]:
        return list(self.additional_properties.keys())

    def __getitem__(self, key: str) -> Any:
        return self.additional_properties[key]

    def __setitem__(self, key: str, value: Any) -> None:
        self.additional_properties[key] = value

    def __delitem__(self, key: str) -> None:
        del self.additional_properties[key]

    def __contains__(self, key: str) -> bool:
        return key in self.additional_properties



from typing import Any, Dict, List, Type, TypeVar, Union, cast

import attr

from ..types import UNSET, Unset

T = TypeVar("T", bound="KeyValueQuery")


@attr.s(auto_attribs=True)
class KeyValueQuery:
    """
    Attributes:
        keys (Union[Unset, List[str]]):
        prefix (Union[Unset, str]):
    """

    keys: Union[Unset, List[str]] = UNSET
    prefix: Union[Unset, str] = UNSET
    additional_properties: Dict[str, Any] = attr.ib(init=False, factory=dict)

    def to_dict(self) -> Dict[str, Any]:
        keys: Union[Unset, List[str]] = UNSET
        if not isinstance(self.keys, Unset):
            keys = self.keys

        prefix = self.prefix

        field_dict: Dict[str, Any] = {}
        field_dict.update(self.additional_properties)
        field_dict.update({})
        if keys is not UNSET:
            field_dict["keys"] = keys
        if prefix is not UNSET:
            field_dict["prefix"] = prefix

        return field_dict

    @classmethod
    def from_dict(cls: Type[T], src_dict: Dict[str, Any]) -> T:
        d = src_dict.copy()
        keys = cast(List[str], d.pop("keys", UNSET))

        prefix = d.pop("prefix", UNSET)

        key_value_query = cls(
            keys=keys,
            prefix=prefix,
        )

        key_value_query.additional_properties = d
        return key_value_query

    @property
    def additional_keys(self) -> List[str]:
        return list(self.additional_properties.keys())

    def __getitem__(self, key: str) -> Any:
        return self.additional_properties[key]

    def __setitem__(self, key: str, value: Any) -> None:
        self.additional_properties[key] = value

    def __delitem__(self, key: str) -> None:
        del self.additional_properties[key]

    def __contains__(self, key: str) -> bool:
        return key in self.additional_properties




from formant.sdk.cloud.v2.formant_query_api_client.models import Quaternion, StreamAggregateDataTags, StreamDataType, StreamDataTags, Video,VideoMimeType, Localization, QueryAggregate, Health, StreamAggregateData, Location, Query, StreamData, StreamDataListResponse, Path, Battery, Map, BoundingBox, QueryTypesItem, VideoMimeType, HealthStatus, NumericSetEntry, ImageAnnotation, StreamAggregateDataType, Goal, Transform, Image, File, Video, Health,HealthStatus, Bitset, Twist, TransformNode, PointCloud, Vector3, StreamDataPointsItem, Odometry
from formant.sdk.cloud.v2.formant_query_api_client.api.query import query_controller_query
from formant.sdk.cloud.v2.formant_query_api_client.types import *



from typing import TYPE_CHECKING, Any, Dict, List, Type, TypeVar

import attr

from ..models.numeric_set_event_trigger_condition_operator import NumericSetEventTriggerConditionOperator
from ..models.numeric_set_event_trigger_condition_type import NumericSetEventTriggerConditionType

if TYPE_CHECKING:
    from ..models.numeric_condition import NumericCondition


T = TypeVar("T", bound="NumericSetEventTriggerCondition")


@attr.s(auto_attribs=True)
class NumericSetEventTriggerCondition:
    """
    Attributes:
        type (NumericSetEventTriggerConditionType):
        conditions (List['NumericCondition']):
        operator (NumericSetEventTriggerConditionOperator):
        stream (str):
    """

    type: NumericSetEventTriggerConditionType
    conditions: List["NumericCondition"]
    operator: NumericSetEventTriggerConditionOperator
    stream: str
    additional_properties: Dict[str, Any] = attr.ib(init=False, factory=dict)

    def to_dict(self) -> Dict[str, Any]:
        type = self.type.value

        conditions = []
        for conditions_item_data in self.conditions:
            conditions_item = conditions_item_data.to_dict()

            conditions.append(conditions_item)

        operator = self.operator.value

        stream = self.stream

        field_dict: Dict[str, Any] = {}
        field_dict.update(self.additional_properties)
        field_dict.update(
            {
                "type": type,
                "conditions": conditions,
                "operator": operator,
                "stream": stream,
            }
        )

        return field_dict

    @classmethod
    def from_dict(cls: Type[T], src_dict: Dict[str, Any]) -> T:
        from ..models.numeric_condition import NumericCondition

        d = src_dict.copy()
        type = NumericSetEventTriggerConditionType(d.pop("type"))

        conditions = []
        _conditions = d.pop("conditions")
        for conditions_item_data in _conditions:
            conditions_item = NumericCondition.from_dict(conditions_item_data)

            conditions.append(conditions_item)

        operator = NumericSetEventTriggerConditionOperator(d.pop("operator"))

        stream = d.pop("stream")

        numeric_set_event_trigger_condition = cls(
            type=type,
            conditions=conditions,
            operator=operator,
            stream=stream,
        )

        numeric_set_event_trigger_condition.additional_properties = d
        return numeric_set_event_trigger_condition

    @property
    def additional_keys(self) -> List[str]:
        return list(self.additional_properties.keys())

    def __getitem__(self, key: str) -> Any:
        return self.additional_properties[key]

    def __setitem__(self, key: str, value: Any) -> None:
        self.additional_properties[key] = value

    def __delitem__(self, key: str) -> None:
        del self.additional_properties[key]

    def __contains__(self, key: str) -> bool:
        return key in self.additional_properties



from typing import Any, Dict, List, Type, TypeVar, Union, cast

import attr

from ..types import UNSET, Unset

T = TypeVar("T", bound="ApplicationContext")


@attr.s(auto_attribs=True)
class ApplicationContext:
    """
    Attributes:
        action (str):
        device_ids (Union[Unset, List[str]]):
    """

    action: str
    device_ids: Union[Unset, List[str]] = UNSET
    additional_properties: Dict[str, Any] = attr.ib(init=False, factory=dict)

    def to_dict(self) -> Dict[str, Any]:
        action = self.action
        device_ids: Union[Unset, List[str]] = UNSET
        if not isinstance(self.device_ids, Unset):
            device_ids = self.device_ids

        field_dict: Dict[str, Any] = {}
        field_dict.update(self.additional_properties)
        field_dict.update(
            {
                "action": action,
            }
        )
        if device_ids is not UNSET:
            field_dict["deviceIds"] = device_ids

        return field_dict

    @classmethod
    def from_dict(cls: Type[T], src_dict: Dict[str, Any]) -> T:
        d = src_dict.copy()
        action = d.pop("action")

        device_ids = cast(List[str], d.pop("deviceIds", UNSET))

        application_context = cls(
            action=action,
            device_ids=device_ids,
        )

        application_context.additional_properties = d
        return application_context

    @property
    def additional_keys(self) -> List[str]:
        return list(self.additional_properties.keys())

    def __getitem__(self, key: str) -> Any:
        return self.additional_properties[key]

    def __setitem__(self, key: str, value: Any) -> None:
        self.additional_properties[key] = value

    def __delitem__(self, key: str) -> None:
        del self.additional_properties[key]

    def __contains__(self, key: str) -> bool:
        return key in self.additional_properties



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: protos/model/v1/navigation.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from formant.protos.model.v1 import math_pb2 as protos_dot_model_dot_v1_dot_math__pb2
from formant.protos.model.v1 import media_pb2 as protos_dot_model_dot_v1_dot_media__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='protos/model/v1/navigation.proto',
  package='v1.model',
  syntax='proto3',
  serialized_options=b'Z)github.com/FormantIO/genproto/go/v1/model',
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n protos/model/v1/navigation.proto\x12\x08v1.model\x1a\x1aprotos/model/v1/math.proto\x1a\x1bprotos/model/v1/media.proto\"}\n\x08Location\x12\x10\n\x08latitude\x18\x01 \x01(\x01\x12\x11\n\tlongitude\x18\x02 \x01(\x01\x12\x15\n\x08\x61ltitude\x18\x03 \x01(\x01H\x00\x88\x01\x01\x12\x18\n\x0borientation\x18\x04 \x01(\x01H\x01\x88\x01\x01\x42\x0b\n\t_altitudeB\x0e\n\x0c_orientation\"\xb8\x01\n\x0cLocalization\x12$\n\x08odometry\x18\x01 \x01(\x0b\x32\x12.v1.model.Odometry\x12\x1a\n\x03map\x18\x02 \x01(\x0b\x32\r.v1.model.Map\x12*\n\x0cpoint_clouds\x18\x03 \x03(\x0b\x32\x14.v1.model.PointCloud\x12\x1c\n\x04path\x18\x04 \x01(\x0b\x32\x0e.v1.model.Path\x12\x1c\n\x04goal\x18\x05 \x01(\x0b\x32\x0e.v1.model.Goal\"z\n\x08Odometry\x12!\n\x04pose\x18\x01 \x01(\x0b\x32\x13.v1.model.Transform\x12\x1e\n\x05twist\x18\x02 \x01(\x0b\x32\x0f.v1.model.Twist\x12+\n\x0eworld_to_local\x18\x03 \x01(\x0b\x32\x13.v1.model.Transform\"\xf1\x01\n\x03Map\x12\x0c\n\x04uuid\x18\t \x01(\t\x12\x12\n\nresolution\x18\x01 \x01(\x01\x12\r\n\x05width\x18\x02 \x01(\r\x12\x0e\n\x06height\x18\x03 \x01(\r\x12#\n\x06origin\x18\x04 \x01(\x0b\x32\x13.v1.model.Transform\x12+\n\x0eworld_to_local\x18\x05 \x01(\x0b\x32\x13.v1.model.Transform\x12\x31\n\x0eoccupancy_grid\x18\x06 \x01(\x0b\x32\x17.v1.model.OccupancyGridH\x00\x12\r\n\x03url\x18\x07 \x01(\tH\x00\x12\r\n\x03raw\x18\x08 \x01(\x0cH\x00\x42\x06\n\x04\x64\x61ta\"\x1d\n\rOccupancyGrid\x12\x0c\n\x04\x64\x61ta\x18\x01 \x03(\x05\"W\n\x04Path\x12+\n\x0eworld_to_local\x18\x01 \x01(\x0b\x32\x13.v1.model.Transform\x12\"\n\x05poses\x18\x02 \x03(\x0b\x32\x13.v1.model.Transform\"{\n\nJointState\x12+\n\x0eworld_to_local\x18\x05 \x01(\x0b\x32\x13.v1.model.Transform\x12\x0c\n\x04name\x18\x01 \x03(\t\x12\x10\n\x08position\x18\x02 \x03(\x01\x12\x10\n\x08velocity\x18\x03 \x03(\x01\x12\x0e\n\x06\x65\x66\x66ort\x18\x04 \x03(\x01\"V\n\x04Goal\x12+\n\x0eworld_to_local\x18\x01 \x01(\x0b\x32\x13.v1.model.Transform\x12!\n\x04pose\x18\x02 \x01(\x0b\x32\x13.v1.model.Transform\"\x14\n\x06GoalID\x12\n\n\x02id\x18\x01 \x01(\t\"K\n\x12PoseWithCovariance\x12!\n\x04pose\x18\x01 \x01(\x0b\x32\x13.v1.model.Transform\x12\x12\n\ncovariance\x18\x02 \x03(\x01\"7\n\tColorRGBA\x12\t\n\x01r\x18\x01 \x01(\x02\x12\t\n\x01g\x18\x02 \x01(\x02\x12\t\n\x01\x62\x18\x03 \x01(\x02\x12\t\n\x01\x61\x18\x04 \x01(\x02\"\xa2\x03\n\x08Marker3D\x12+\n\x0eworld_to_local\x18\x01 \x01(\x0b\x32\x13.v1.model.Transform\x12\n\n\x02ns\x18\x02 \x01(\t\x12\n\n\x02id\x18\x03 \x01(\x05\x12\x0c\n\x04type\x18\x04 \x01(\t\x12\x0e\n\x06\x61\x63tion\x18\x05 \x01(\t\x12!\n\x04pose\x18\x06 \x01(\x0b\x32\x13.v1.model.Transform\x12 \n\x05scale\x18\x07 \x01(\x0b\x32\x11.v1.model.Vector3\x12\"\n\x05\x63olor\x18\x08 \x01(\x0b\x32\x13.v1.model.ColorRGBA\x12\x10\n\x08lifetime\x18\t \x01(\x01\x12\x14\n\x0c\x66rame_locked\x18\n \x01(\x08\x12!\n\x06points\x18\x0b \x03(\x0b\x32\x11.v1.model.Vector3\x12#\n\x06\x63olors\x18\x0c \x03(\x0b\x32\x13.v1.model.ColorRGBA\x12\x0c\n\x04text\x18\r \x01(\t\x12\x15\n\rmesh_resource\x18\x0e \x01(\t\x12#\n\x1bmesh_use_embedded_materials\x18\x0f \x01(\x08\x12\x10\n\x08\x66rame_id\x18\x10 \x01(\t\"4\n\rMarker3DArray\x12#\n\x07markers\x18\x01 \x03(\x0b\x32\x12.v1.model.Marker3D\"$\n\x03Joy\x12\x0c\n\x04\x61xes\x18\x01 \x03(\x02\x12\x0f\n\x07\x62uttons\x18\x02 \x03(\x05\x42+Z)github.com/FormantIO/genproto/go/v1/modelb\x06proto3'
  ,
  dependencies=[protos_dot_model_dot_v1_dot_math__pb2.DESCRIPTOR,protos_dot_model_dot_v1_dot_media__pb2.DESCRIPTOR,])




_LOCATION = _descriptor.Descriptor(
  name='Location',
  full_name='v1.model.Location',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='latitude', full_name='v1.model.Location.latitude', index=0,
      number=1, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='longitude', full_name='v1.model.Location.longitude', index=1,
      number=2, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='altitude', full_name='v1.model.Location.altitude', index=2,
      number=3, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='orientation', full_name='v1.model.Location.orientation', index=3,
      number=4, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='_altitude', full_name='v1.model.Location._altitude',
      index=0, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
    _descriptor.OneofDescriptor(
      name='_orientation', full_name='v1.model.Location._orientation',
      index=1, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
  ],
  serialized_start=103,
  serialized_end=228,
)


_LOCALIZATION = _descriptor.Descriptor(
  name='Localization',
  full_name='v1.model.Localization',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='odometry', full_name='v1.model.Localization.odometry', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='map', full_name='v1.model.Localization.map', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='point_clouds', full_name='v1.model.Localization.point_clouds', index=2,
      number=3, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='path', full_name='v1.model.Localization.path', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='goal', full_name='v1.model.Localization.goal', index=4,
      number=5, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=231,
  serialized_end=415,
)


_ODOMETRY = _descriptor.Descriptor(
  name='Odometry',
  full_name='v1.model.Odometry',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='pose', full_name='v1.model.Odometry.pose', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='twist', full_name='v1.model.Odometry.twist', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='world_to_local', full_name='v1.model.Odometry.world_to_local', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=417,
  serialized_end=539,
)


_MAP = _descriptor.Descriptor(
  name='Map',
  full_name='v1.model.Map',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='uuid', full_name='v1.model.Map.uuid', index=0,
      number=9, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='resolution', full_name='v1.model.Map.resolution', index=1,
      number=1, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='width', full_name='v1.model.Map.width', index=2,
      number=2, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='height', full_name='v1.model.Map.height', index=3,
      number=3, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='origin', full_name='v1.model.Map.origin', index=4,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='world_to_local', full_name='v1.model.Map.world_to_local', index=5,
      number=5, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='occupancy_grid', full_name='v1.model.Map.occupancy_grid', index=6,
      number=6, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='url', full_name='v1.model.Map.url', index=7,
      number=7, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='raw', full_name='v1.model.Map.raw', index=8,
      number=8, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=b"",
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='data', full_name='v1.model.Map.data',
      index=0, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
  ],
  serialized_start=542,
  serialized_end=783,
)


_OCCUPANCYGRID = _descriptor.Descriptor(
  name='OccupancyGrid',
  full_name='v1.model.OccupancyGrid',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='data', full_name='v1.model.OccupancyGrid.data', index=0,
      number=1, type=5, cpp_type=1, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=785,
  serialized_end=814,
)


_PATH = _descriptor.Descriptor(
  name='Path',
  full_name='v1.model.Path',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='world_to_local', full_name='v1.model.Path.world_to_local', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='poses', full_name='v1.model.Path.poses', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=816,
  serialized_end=903,
)


_JOINTSTATE = _descriptor.Descriptor(
  name='JointState',
  full_name='v1.model.JointState',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='world_to_local', full_name='v1.model.JointState.world_to_local', index=0,
      number=5, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='name', full_name='v1.model.JointState.name', index=1,
      number=1, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='position', full_name='v1.model.JointState.position', index=2,
      number=2, type=1, cpp_type=5, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='velocity', full_name='v1.model.JointState.velocity', index=3,
      number=3, type=1, cpp_type=5, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='effort', full_name='v1.model.JointState.effort', index=4,
      number=4, type=1, cpp_type=5, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=905,
  serialized_end=1028,
)


_GOAL = _descriptor.Descriptor(
  name='Goal',
  full_name='v1.model.Goal',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='world_to_local', full_name='v1.model.Goal.world_to_local', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='pose', full_name='v1.model.Goal.pose', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1030,
  serialized_end=1116,
)


_GOALID = _descriptor.Descriptor(
  name='GoalID',
  full_name='v1.model.GoalID',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='id', full_name='v1.model.GoalID.id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1118,
  serialized_end=1138,
)


_POSEWITHCOVARIANCE = _descriptor.Descriptor(
  name='PoseWithCovariance',
  full_name='v1.model.PoseWithCovariance',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='pose', full_name='v1.model.PoseWithCovariance.pose', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='covariance', full_name='v1.model.PoseWithCovariance.covariance', index=1,
      number=2, type=1, cpp_type=5, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1140,
  serialized_end=1215,
)


_COLORRGBA = _descriptor.Descriptor(
  name='ColorRGBA',
  full_name='v1.model.ColorRGBA',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='r', full_name='v1.model.ColorRGBA.r', index=0,
      number=1, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='g', full_name='v1.model.ColorRGBA.g', index=1,
      number=2, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='b', full_name='v1.model.ColorRGBA.b', index=2,
      number=3, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='a', full_name='v1.model.ColorRGBA.a', index=3,
      number=4, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1217,
  serialized_end=1272,
)


_MARKER3D = _descriptor.Descriptor(
  name='Marker3D',
  full_name='v1.model.Marker3D',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='world_to_local', full_name='v1.model.Marker3D.world_to_local', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='ns', full_name='v1.model.Marker3D.ns', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='id', full_name='v1.model.Marker3D.id', index=2,
      number=3, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='type', full_name='v1.model.Marker3D.type', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='action', full_name='v1.model.Marker3D.action', index=4,
      number=5, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='pose', full_name='v1.model.Marker3D.pose', index=5,
      number=6, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='scale', full_name='v1.model.Marker3D.scale', index=6,
      number=7, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='color', full_name='v1.model.Marker3D.color', index=7,
      number=8, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='lifetime', full_name='v1.model.Marker3D.lifetime', index=8,
      number=9, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='frame_locked', full_name='v1.model.Marker3D.frame_locked', index=9,
      number=10, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='points', full_name='v1.model.Marker3D.points', index=10,
      number=11, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='colors', full_name='v1.model.Marker3D.colors', index=11,
      number=12, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='text', full_name='v1.model.Marker3D.text', index=12,
      number=13, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='mesh_resource', full_name='v1.model.Marker3D.mesh_resource', index=13,
      number=14, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='mesh_use_embedded_materials', full_name='v1.model.Marker3D.mesh_use_embedded_materials', index=14,
      number=15, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='frame_id', full_name='v1.model.Marker3D.frame_id', index=15,
      number=16, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1275,
  serialized_end=1693,
)


_MARKER3DARRAY = _descriptor.Descriptor(
  name='Marker3DArray',
  full_name='v1.model.Marker3DArray',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='markers', full_name='v1.model.Marker3DArray.markers', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1695,
  serialized_end=1747,
)


_JOY = _descriptor.Descriptor(
  name='Joy',
  full_name='v1.model.Joy',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='axes', full_name='v1.model.Joy.axes', index=0,
      number=1, type=2, cpp_type=6, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='buttons', full_name='v1.model.Joy.buttons', index=1,
      number=2, type=5, cpp_type=1, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1749,
  serialized_end=1785,
)

_LOCATION.oneofs_by_name['_altitude'].fields.append(
  _LOCATION.fields_by_name['altitude'])
_LOCATION.fields_by_name['altitude'].containing_oneof = _LOCATION.oneofs_by_name['_altitude']
_LOCATION.oneofs_by_name['_orientation'].fields.append(
  _LOCATION.fields_by_name['orientation'])
_LOCATION.fields_by_name['orientation'].containing_oneof = _LOCATION.oneofs_by_name['_orientation']
_LOCALIZATION.fields_by_name['odometry'].message_type = _ODOMETRY
_LOCALIZATION.fields_by_name['map'].message_type = _MAP
_LOCALIZATION.fields_by_name['point_clouds'].message_type = protos_dot_model_dot_v1_dot_media__pb2._POINTCLOUD
_LOCALIZATION.fields_by_name['path'].message_type = _PATH
_LOCALIZATION.fields_by_name['goal'].message_type = _GOAL
_ODOMETRY.fields_by_name['pose'].message_type = protos_dot_model_dot_v1_dot_math__pb2._TRANSFORM
_ODOMETRY.fields_by_name['twist'].message_type = protos_dot_model_dot_v1_dot_math__pb2._TWIST
_ODOMETRY.fields_by_name['world_to_local'].message_type = protos_dot_model_dot_v1_dot_math__pb2._TRANSFORM
_MAP.fields_by_name['origin'].message_type = protos_dot_model_dot_v1_dot_math__pb2._TRANSFORM
_MAP.fields_by_name['world_to_local'].message_type = protos_dot_model_dot_v1_dot_math__pb2._TRANSFORM
_MAP.fields_by_name['occupancy_grid'].message_type = _OCCUPANCYGRID
_MAP.oneofs_by_name['data'].fields.append(
  _MAP.fields_by_name['occupancy_grid'])
_MAP.fields_by_name['occupancy_grid'].containing_oneof = _MAP.oneofs_by_name['data']
_MAP.oneofs_by_name['data'].fields.append(
  _MAP.fields_by_name['url'])
_MAP.fields_by_name['url'].containing_oneof = _MAP.oneofs_by_name['data']
_MAP.oneofs_by_name['data'].fields.append(
  _MAP.fields_by_name['raw'])
_MAP.fields_by_name['raw'].containing_oneof = _MAP.oneofs_by_name['data']
_PATH.fields_by_name['world_to_local'].message_type = protos_dot_model_dot_v1_dot_math__pb2._TRANSFORM
_PATH.fields_by_name['poses'].message_type = protos_dot_model_dot_v1_dot_math__pb2._TRANSFORM
_JOINTSTATE.fields_by_name['world_to_local'].message_type = protos_dot_model_dot_v1_dot_math__pb2._TRANSFORM
_GOAL.fields_by_name['world_to_local'].message_type = protos_dot_model_dot_v1_dot_math__pb2._TRANSFORM
_GOAL.fields_by_name['pose'].message_type = protos_dot_model_dot_v1_dot_math__pb2._TRANSFORM
_POSEWITHCOVARIANCE.fields_by_name['pose'].message_type = protos_dot_model_dot_v1_dot_math__pb2._TRANSFORM
_MARKER3D.fields_by_name['world_to_local'].message_type = protos_dot_model_dot_v1_dot_math__pb2._TRANSFORM
_MARKER3D.fields_by_name['pose'].message_type = protos_dot_model_dot_v1_dot_math__pb2._TRANSFORM
_MARKER3D.fields_by_name['scale'].message_type = protos_dot_model_dot_v1_dot_math__pb2._VECTOR3
_MARKER3D.fields_by_name['color'].message_type = _COLORRGBA
_MARKER3D.fields_by_name['points'].message_type = protos_dot_model_dot_v1_dot_math__pb2._VECTOR3
_MARKER3D.fields_by_name['colors'].message_type = _COLORRGBA
_MARKER3DARRAY.fields_by_name['markers'].message_type = _MARKER3D
DESCRIPTOR.message_types_by_name['Location'] = _LOCATION
DESCRIPTOR.message_types_by_name['Localization'] = _LOCALIZATION
DESCRIPTOR.message_types_by_name['Odometry'] = _ODOMETRY
DESCRIPTOR.message_types_by_name['Map'] = _MAP
DESCRIPTOR.message_types_by_name['OccupancyGrid'] = _OCCUPANCYGRID
DESCRIPTOR.message_types_by_name['Path'] = _PATH
DESCRIPTOR.message_types_by_name['JointState'] = _JOINTSTATE
DESCRIPTOR.message_types_by_name['Goal'] = _GOAL
DESCRIPTOR.message_types_by_name['GoalID'] = _GOALID
DESCRIPTOR.message_types_by_name['PoseWithCovariance'] = _POSEWITHCOVARIANCE
DESCRIPTOR.message_types_by_name['ColorRGBA'] = _COLORRGBA
DESCRIPTOR.message_types_by_name['Marker3D'] = _MARKER3D
DESCRIPTOR.message_types_by_name['Marker3DArray'] = _MARKER3DARRAY
DESCRIPTOR.message_types_by_name['Joy'] = _JOY
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

Location = _reflection.GeneratedProtocolMessageType('Location', (_message.Message,), {
  'DESCRIPTOR' : _LOCATION,
  '__module__' : 'protos.model.v1.navigation_pb2'
  # @@protoc_insertion_point(class_scope:v1.model.Location)
  })
_sym_db.RegisterMessage(Location)

Localization = _reflection.GeneratedProtocolMessageType('Localization', (_message.Message,), {
  'DESCRIPTOR' : _LOCALIZATION,
  '__module__' : 'protos.model.v1.navigation_pb2'
  # @@protoc_insertion_point(class_scope:v1.model.Localization)
  })
_sym_db.RegisterMessage(Localization)

Odometry = _reflection.GeneratedProtocolMessageType('Odometry', (_message.Message,), {
  'DESCRIPTOR' : _ODOMETRY,
  '__module__' : 'protos.model.v1.navigation_pb2'
  # @@protoc_insertion_point(class_scope:v1.model.Odometry)
  })
_sym_db.RegisterMessage(Odometry)

Map = _reflection.GeneratedProtocolMessageType('Map', (_message.Message,), {
  'DESCRIPTOR' : _MAP,
  '__module__' : 'protos.model.v1.navigation_pb2'
  # @@protoc_insertion_point(class_scope:v1.model.Map)
  })
_sym_db.RegisterMessage(Map)

OccupancyGrid = _reflection.GeneratedProtocolMessageType('OccupancyGrid', (_message.Message,), {
  'DESCRIPTOR' : _OCCUPANCYGRID,
  '__module__' : 'protos.model.v1.navigation_pb2'
  # @@protoc_insertion_point(class_scope:v1.model.OccupancyGrid)
  })
_sym_db.RegisterMessage(OccupancyGrid)

Path = _reflection.GeneratedProtocolMessageType('Path', (_message.Message,), {
  'DESCRIPTOR' : _PATH,
  '__module__' : 'protos.model.v1.navigation_pb2'
  # @@protoc_insertion_point(class_scope:v1.model.Path)
  })
_sym_db.RegisterMessage(Path)

JointState = _reflection.GeneratedProtocolMessageType('JointState', (_message.Message,), {
  'DESCRIPTOR' : _JOINTSTATE,
  '__module__' : 'protos.model.v1.navigation_pb2'
  # @@protoc_insertion_point(class_scope:v1.model.JointState)
  })
_sym_db.RegisterMessage(JointState)

Goal = _reflection.GeneratedProtocolMessageType('Goal', (_message.Message,), {
  'DESCRIPTOR' : _GOAL,
  '__module__' : 'protos.model.v1.navigation_pb2'
  # @@protoc_insertion_point(class_scope:v1.model.Goal)
  })
_sym_db.RegisterMessage(Goal)

GoalID = _reflection.GeneratedProtocolMessageType('GoalID', (_message.Message,), {
  'DESCRIPTOR' : _GOALID,
  '__module__' : 'protos.model.v1.navigation_pb2'
  # @@protoc_insertion_point(class_scope:v1.model.GoalID)
  })
_sym_db.RegisterMessage(GoalID)

PoseWithCovariance = _reflection.GeneratedProtocolMessageType('PoseWithCovariance', (_message.Message,), {
  'DESCRIPTOR' : _POSEWITHCOVARIANCE,
  '__module__' : 'protos.model.v1.navigation_pb2'
  # @@protoc_insertion_point(class_scope:v1.model.PoseWithCovariance)
  })
_sym_db.RegisterMessage(PoseWithCovariance)

ColorRGBA = _reflection.GeneratedProtocolMessageType('ColorRGBA', (_message.Message,), {
  'DESCRIPTOR' : _COLORRGBA,
  '__module__' : 'protos.model.v1.navigation_pb2'
  # @@protoc_insertion_point(class_scope:v1.model.ColorRGBA)
  })
_sym_db.RegisterMessage(ColorRGBA)

Marker3D = _reflection.GeneratedProtocolMessageType('Marker3D', (_message.Message,), {
  'DESCRIPTOR' : _MARKER3D,
  '__module__' : 'protos.model.v1.navigation_pb2'
  # @@protoc_insertion_point(class_scope:v1.model.Marker3D)
  })
_sym_db.RegisterMessage(Marker3D)

Marker3DArray = _reflection.GeneratedProtocolMessageType('Marker3DArray', (_message.Message,), {
  'DESCRIPTOR' : _MARKER3DARRAY,
  '__module__' : 'protos.model.v1.navigation_pb2'
  # @@protoc_insertion_point(class_scope:v1.model.Marker3DArray)
  })
_sym_db.RegisterMessage(Marker3DArray)

Joy = _reflection.GeneratedProtocolMessageType('Joy', (_message.Message,), {
  'DESCRIPTOR' : _JOY,
  '__module__' : 'protos.model.v1.navigation_pb2'
  # @@protoc_insertion_point(class_scope:v1.model.Joy)
  })
_sym_db.RegisterMessage(Joy)


DESCRIPTOR._options = None
# @@protoc_insertion_point(module_scope)



from typing import Any, Dict, List, Type, TypeVar

import attr

T = TypeVar("T", bound="ConfirmForgotPasswordRequest")


@attr.s(auto_attribs=True)
class ConfirmForgotPasswordRequest:
    """
    Attributes:
        email (str):
        confirmation_code (str):
        new_password (str):
    """

    email: str
    confirmation_code: str
    new_password: str
    additional_properties: Dict[str, Any] = attr.ib(init=False, factory=dict)

    def to_dict(self) -> Dict[str, Any]:
        email = self.email
        confirmation_code = self.confirmation_code
        new_password = self.new_password

        field_dict: Dict[str, Any] = {}
        field_dict.update(self.additional_properties)
        field_dict.update(
            {
                "email": email,
                "confirmationCode": confirmation_code,
                "newPassword": new_password,
            }
        )

        return field_dict

    @classmethod
    def from_dict(cls: Type[T], src_dict: Dict[str, Any]) -> T:
        d = src_dict.copy()
        email = d.pop("email")

        confirmation_code = d.pop("confirmationCode")

        new_password = d.pop("newPassword")

        confirm_forgot_password_request = cls(
            email=email,
            confirmation_code=confirmation_code,
            new_password=new_password,
        )

        confirm_forgot_password_request.additional_properties = d
        return confirm_forgot_password_request

    @property
    def additional_keys(self) -> List[str]:
        return list(self.additional_properties.keys())

    def __getitem__(self, key: str) -> Any:
        return self.additional_properties[key]

    def __setitem__(self, key: str, value: Any) -> None:
        self.additional_properties[key] = value

    def __delitem__(self, key: str) -> None:
        del self.additional_properties[key]

    def __contains__(self, key: str) -> bool:
        return key in self.additional_properties



from enum import Enum


class UserParametersRolesItem(str, Enum):
    VIEWER = "viewer"
    OPERATOR = "operator"
    ADMINISTRATOR = "administrator"

    def __str__(self) -> str:
        return str(self.value)



from typing import Any, Dict, List, Type, TypeVar, Union

import attr

from ..types import UNSET, Unset

T = TypeVar("T", bound="ChatMessageRequest")


@attr.s(auto_attribs=True)
class ChatMessageRequest:
    """
    Attributes:
        message (str):
        system_context_override (Union[Unset, str]):
    """

    message: str
    system_context_override: Union[Unset, str] = UNSET
    additional_properties: Dict[str, Any] = attr.ib(init=False, factory=dict)

    def to_dict(self) -> Dict[str, Any]:
        message = self.message
        system_context_override = self.system_context_override

        field_dict: Dict[str, Any] = {}
        field_dict.update(self.additional_properties)
        field_dict.update(
            {
                "message": message,
            }
        )
        if system_context_override is not UNSET:
            field_dict["systemContextOverride"] = system_context_override

        return field_dict

    @classmethod
    def from_dict(cls: Type[T], src_dict: Dict[str, Any]) -> T:
        d = src_dict.copy()
        message = d.pop("message")

        system_context_override = d.pop("systemContextOverride", UNSET)

        chat_message_request = cls(
            message=message,
            system_context_override=system_context_override,
        )

        chat_message_request.additional_properties = d
        return chat_message_request

    @property
    def additional_keys(self) -> List[str]:
        return list(self.additional_properties.keys())

    def __getitem__(self, key: str) -> Any:
        return self.additional_properties[key]

    def __setitem__(self, key: str, value: Any) -> None:
        self.additional_properties[key] = value

    def __delitem__(self, key: str) -> None:
        del self.additional_properties[key]

    def __contains__(self, key: str) -> bool:
        return key in self.additional_properties



from enum import Enum


class DeviceStreamDirectoryWatchConfigurationFileType(str, Enum):
    FILE = "file"
    IMAGE = "image"
    VIDEO = "video"
    POINT_CLOUD = "point-cloud"

    def __str__(self) -> str:
        return str(self.value)



from typing import TYPE_CHECKING, Any, Dict, List, Type, TypeVar, Union

import attr

from ..types import UNSET, Unset

if TYPE_CHECKING:
    from ..models.stream_aggregate_data import StreamAggregateData
    from ..models.stream_data import StreamData


T = TypeVar("T", bound="StreamDataListResponse")


@attr.s(auto_attribs=True)
class StreamDataListResponse:
    """
    Attributes:
        items (List['StreamData']):
        aggregates (Union[Unset, List['StreamAggregateData']]):
        next_ (Union[Unset, Any]):
    """

    items: List["StreamData"]
    aggregates: Union[Unset, List["StreamAggregateData"]] = UNSET
    next_: Union[Unset, Any] = UNSET
    additional_properties: Dict[str, Any] = attr.ib(init=False, factory=dict)

    def to_dict(self) -> Dict[str, Any]:
        items = []
        for items_item_data in self.items:
            items_item = items_item_data.to_dict()

            items.append(items_item)

        aggregates: Union[Unset, List[Dict[str, Any]]] = UNSET
        if not isinstance(self.aggregates, Unset):
            aggregates = []
            for aggregates_item_data in self.aggregates:
                aggregates_item = aggregates_item_data.to_dict()

                aggregates.append(aggregates_item)

        next_ = self.next_

        field_dict: Dict[str, Any] = {}
        field_dict.update(self.additional_properties)
        field_dict.update(
            {
                "items": items,
            }
        )
        if aggregates is not UNSET:
            field_dict["aggregates"] = aggregates
        if next_ is not UNSET:
            field_dict["next"] = next_

        return field_dict

    @classmethod
    def from_dict(cls: Type[T], src_dict: Dict[str, Any]) -> T:
        from ..models.stream_aggregate_data import StreamAggregateData
        from ..models.stream_data import StreamData

        d = src_dict.copy()
        items = []
        _items = d.pop("items")
        for items_item_data in _items:
            items_item = StreamData.from_dict(items_item_data)

            items.append(items_item)

        aggregates = []
        _aggregates = d.pop("aggregates", UNSET)
        for aggregates_item_data in _aggregates or []:
            aggregates_item = StreamAggregateData.from_dict(aggregates_item_data)

            aggregates.append(aggregates_item)

        next_ = d.pop("next", UNSET)

        stream_data_list_response = cls(
            items=items,
            aggregates=aggregates,
            next_=next_,
        )

        stream_data_list_response.additional_properties = d
        return stream_data_list_response

    @property
    def additional_keys(self) -> List[str]:
        return list(self.additional_properties.keys())

    def __getitem__(self, key: str) -> Any:
        return self.additional_properties[key]

    def __setitem__(self, key: str, value: Any) -> None:
        self.additional_properties[key] = value

    def __delitem__(self, key: str) -> None:
        del self.additional_properties[key]

    def __contains__(self, key: str) -> bool:
        return key in self.additional_properties



from typing import TYPE_CHECKING, Any, Dict, List, Type, TypeVar, Union

import attr

from ..types import UNSET, Unset

if TYPE_CHECKING:
    from ..models.stripe_card import StripeCard


T = TypeVar("T", bound="StripeInfo")


@attr.s(auto_attribs=True)
class StripeInfo:
    """
    Attributes:
        customer_id (str):
        subscription_id (Union[Unset, str]):
        card (Union[Unset, StripeCard]):
        billing_anchor (Union[Unset, int]):
    """

    customer_id: str
    subscription_id: Union[Unset, str] = UNSET
    card: Union[Unset, "StripeCard"] = UNSET
    billing_anchor: Union[Unset, int] = UNSET
    additional_properties: Dict[str, Any] = attr.ib(init=False, factory=dict)

    def to_dict(self) -> Dict[str, Any]:
        customer_id = self.customer_id
        subscription_id = self.subscription_id
        card: Union[Unset, Dict[str, Any]] = UNSET
        if not isinstance(self.card, Unset):
            card = self.card.to_dict()

        billing_anchor = self.billing_anchor

        field_dict: Dict[str, Any] = {}
        field_dict.update(self.additional_properties)
        field_dict.update(
            {
                "customerId": customer_id,
            }
        )
        if subscription_id is not UNSET:
            field_dict["subscriptionId"] = subscription_id
        if card is not UNSET:
            field_dict["card"] = card
        if billing_anchor is not UNSET:
            field_dict["billingAnchor"] = billing_anchor

        return field_dict

    @classmethod
    def from_dict(cls: Type[T], src_dict: Dict[str, Any]) -> T:
        from ..models.stripe_card import StripeCard

        d = src_dict.copy()
        customer_id = d.pop("customerId")

        subscription_id = d.pop("subscriptionId", UNSET)

        _card = d.pop("card", UNSET)
        card: Union[Unset, StripeCard]
        if isinstance(_card, Unset):
            card = UNSET
        else:
            card = StripeCard.from_dict(_card)

        billing_anchor = d.pop("billingAnchor", UNSET)

        stripe_info = cls(
            customer_id=customer_id,
            subscription_id=subscription_id,
            card=card,
            billing_anchor=billing_anchor,
        )

        stripe_info.additional_properties = d
        return stripe_info

    @property
    def additional_keys(self) -> List[str]:
        return list(self.additional_properties.keys())

    def __getitem__(self, key: str) -> Any:
        return self.additional_properties[key]

    def __setitem__(self, key: str, value: Any) -> None:
        self.additional_properties[key] = value

    def __delitem__(self, key: str) -> None:
        del self.additional_properties[key]

    def __contains__(self, key: str) -> bool:
        return key in self.additional_properties



from typing import Any, Dict, List, Type, TypeVar

import attr

T = TypeVar("T", bound="DeviceProvisioningRequest")


@attr.s(auto_attribs=True)
class DeviceProvisioningRequest:
    """
    Attributes:
        provisioning_token (str):
        public_key (str):
    """

    provisioning_token: str
    public_key: str
    additional_properties: Dict[str, Any] = attr.ib(init=False, factory=dict)

    def to_dict(self) -> Dict[str, Any]:
        provisioning_token = self.provisioning_token
        public_key = self.public_key

        field_dict: Dict[str, Any] = {}
        field_dict.update(self.additional_properties)
        field_dict.update(
            {
                "provisioningToken": provisioning_token,
                "publicKey": public_key,
            }
        )

        return field_dict

    @classmethod
    def from_dict(cls: Type[T], src_dict: Dict[str, Any]) -> T:
        d = src_dict.copy()
        provisioning_token = d.pop("provisioningToken")

        public_key = d.pop("publicKey")

        device_provisioning_request = cls(
            provisioning_token=provisioning_token,
            public_key=public_key,
        )

        device_provisioning_request.additional_properties = d
        return device_provisioning_request

    @property
    def additional_keys(self) -> List[str]:
        return list(self.additional_properties.keys())

    def __getitem__(self, key: str) -> Any:
        return self.additional_properties[key]

    def __setitem__(self, key: str, value: Any) -> None:
        self.additional_properties[key] = value

    def __delitem__(self, key: str) -> None:
        del self.additional_properties[key]

    def __contains__(self, key: str) -> bool:
        return key in self.additional_properties



from enum import Enum


class DeviceTeleopHardwareStreamConfigurationQuality(str, Enum):
    VALUE_0 = "1080p"
    VALUE_1 = "720p"
    VALUE_2 = "480p"
    VALUE_3 = "360p"

    def __str__(self) -> str:
        return str(self.value)



# flake8: noqa
import sys
from .v1 import Client

if sys.version_info >= (3, 6) and __name__ == "formant.sdk.cloud":
    from .v2 import Client as ClientV2

    sys.modules.update({"formant.sdk.cloud.ClientV2": ClientV2})
